### Name: readRAST6
### Title: Read and write GRASS 6 raster files
### Aliases: readRAST6 readBinGrid writeRAST6 writeBinGrid rast.get6
###   rast.put6 readCELL6sp readFLOAT6sp writeRast6sp
### Keywords: spatial

### ** Examples

if (nchar(Sys.getenv("GISRC")) > 0) {
  spear <- readRAST6(c("geology", "elevation.dem"), cat=c(TRUE, FALSE),
    ignore.stderr=TRUE, plugin=NULL)
  spear <- readRAST6(c("geology", "elevation.dem"), cat=c(TRUE, FALSE),
    ignore.stderr=TRUE, useGDAL=FALSE, plugin=FALSE)
  spear <- readRAST6(c("geology", "elevation.dem"), cat=c(TRUE, FALSE),
    ignore.stderr=TRUE, useGDAL=TRUE, plugin=FALSE)
  print(table(spear$geology))
  execGRASS("r.stats", flags=c("c", "l", "quiet"), 
    parameters=list(input="geology"), ignore.stderr=TRUE)
  boxplot(spear$elevation.dem ~ spear$geology)
  spear$sqdem <- sqrt(spear$elevation.dem)
  if ("GRASS" %in% gdalDrivers()$name) {
    dem1 <- readRAST6("elevation.dem", plugin=TRUE, ignore.stderr=TRUE,
      mapset="PERMANENT")
    print(summary(dem1))
  }
  writeRAST6(spear, "sqdemSP", zcol="sqdem", ignore.stderr=TRUE)
  execGRASS("r.info", parameters=list(map="sqdemSP"), ignore.stderr=TRUE)
  execGRASS("g.remove", parameters=list(rast="sqdemSP"), ignore.stderr=TRUE)
  writeRAST6(spear, "sqdemSP", zcol="sqdem", ignore.stderr=TRUE, useGDAL=TRUE)
  execGRASS("r.info", parameters=list(map="sqdemSP"), ignore.stderr=TRUE)
  execGRASS("g.remove", parameters=list(rast="sqdemSP"), ignore.stderr=TRUE)
  execGRASS("r.mapcalculator", parameters=list(outfile="quads0",
    amap="quads", formula='A - 1'), ignore.stderr=TRUE)
  execGRASS("r.stats", flags="c", parameters=list(input="quads0"),
    ignore.stderr=TRUE)
  quads0 <- readRAST6("quads0", ignore.stderr=TRUE)
  print(table(quads0$quads0))
  quads0 <- readRAST6("quads0", ignore.stderr=TRUE, plugin=FALSE)
  print(table(quads0$quads0))
  execGRASS("g.remove", parameters=list(rast="quads0"), ignore.stderr=TRUE)
}



